@@ -38,9 +38,10 @@
 #' @method print microbenchmark
 #' @author Olaf Mersmann
 print.microbenchmark <- function(x, unit, order, signif, ...) {
-  if (!missing(unit)) {
-    unit <- normalize_unit(unit)
+  if (missing(unit)) {
+    unit <- NULL
   }
+  unit <- determine_unit(x, unit)
   s <- summary(x, unit=unit)
   timing_cols <- c("min", "lq", "median", "uq", "max", "mean")
   if (!missing(signif)) {
